==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojox/README.md <==
# dojox

**dojox** is a meta-package of other packages that was historically a development area for the Dojo Toolkit.  It
contains packages that run the gamut of JavaScript technology.  Over the years the modules and sub-packages have taken 
dramatically different paths.  Some of the code is very mature, some of the code is experimental and some of the code is
essentially abandoned.  All of the packages require the Dojo Toolkit [core][] and some require the widget library
[dijit][].

You should read the ``README`` file contained in each sub-package to understand the status of the code contained
within.

DojoX is currently not accepting any new sub-packages or projects.  There are many community packages available at
[Dojo Foundation Packages][] and additional packages can be registered there as well.  If you are interested in adding
to the community of packages, please discuss in the [Community Forum][].

## Installing

Installation instructions are available at [dojotoolkit.org/download][download].

## Getting Started

If you are starting out with Dojo, the following resources are available to you:

* [Tutorials][]
* [Reference Guide][]
* [API Documentation][]
* [Community Forum][]

## License and Copyright

The Dojo Toolkit (including this package) is dual licensed under BSD 3-Clause and AFL.  For more information on the
license please see the [License Information][].  The Dojo Toolkit is Copyright (c) 2005-2016, The Dojo Foundation.  All
rights reserved.

[core]: https://github.com/dojo/dojo/
[dijit]: https://github.com/dojo/dijit/
[download]: http://dojotoolkit.org/download/
[Tutorials]: http://dojotoolkit.org/documentation/
[Reference Guide]: http://dojotoolkit.org/reference-guide/
[API Documentation]: http://dojotoolkit.org/api/
[Community Forum]: http://dojotoolkit.org/community/
[License Information]: http://dojotoolkit.org/license
[Dojo Foundation Packages]: http://packages.dojofoundation.org/

==> dojo_1.14.2+dfsg1.orig.tar.gz: dojo-release-1.14.2-src/dojox/README.md <==
# dojox

**dojox** is a meta-package of other packages that was historically a development area for the Dojo Toolkit.  It
contains packages that run the gamut of JavaScript technology.  Over the years the modules and sub-packages have taken 
dramatically different paths.  Some of the code is very mature, some of the code is experimental and some of the code is
essentially abandoned.  All of the packages require the Dojo Toolkit [core][] and some require the widget library
[dijit][].

You should read the ``README`` file contained in each sub-package to understand the status of the code contained
within.

DojoX is currently not accepting any new sub-packages or projects.  If you are interested in adding
to the community of packages, please discuss in the [Community Forum][].

## Installing

Installation instructions are available at [dojotoolkit.org/download][download].

## Getting Started

If you are starting out with Dojo, the following resources are available to you:

* [Tutorials][]
* [Reference Guide][]
* [API Documentation][]
* [Community Forum][]

## License and Copyright

The Dojo Toolkit (including this package) is dual licensed under BSD 3-Clause and AFL.  For more information on the
license please see the [License Information][].  The Dojo Toolkit is Copyright (c) 2005-2016, The JS Foundation.  All
rights reserved.

[core]: https://github.com/dojo/dojo/
[dijit]: https://github.com/dojo/dijit/
[download]: http://dojotoolkit.org/download/
[Tutorials]: http://dojotoolkit.org/documentation/
[Reference Guide]: http://dojotoolkit.org/reference-guide/
[API Documentation]: http://dojotoolkit.org/api/
[Community Forum]: http://dojotoolkit.org/community/
[License Information]: http://dojotoolkit.org/license
